@@ -1,3 +1,6 @@
+from functools import reduce
+from operator import or_
+
 from django.apps import apps
 from django.contrib.auth.models import User
 from django.db import connection
@@ -9,7 +12,7 @@ from django.db.models.sql.query import Query
 from django.utils.translation import gettext_lazy as _
 
 from . import shunting_yard
-from .helpers import get_model_obj
+from .model_helpers import get_model_obj
 from .utils import (
     previous,
     str_as_date, 
@@ -118,8 +121,16 @@ class DynamicFilterTerm(models.Model):
 
     def __str__(self):
         if self.op in ('-', '!'):
-            comparison = '!=' if self.op == '!' else '=='
-            return f'{self.get_keypath()} {comparison} {self.get_value()}'
+            string = ' OR '.join([
+                f'{self.get_keypath(field)} {operator} {self.get_value()}'
+                for field in self.field.split('|')
+            ])
+
+            return (
+                f'NOT({string})'
+                if self.op == '!' else
+                string
+            )
 
         return self.op
 
@@ -135,14 +146,14 @@ class DynamicFilterTerm(models.Model):
             if self.lookup in ('isnull', 'isnotnull', 'istrue', 'isfalse'):
                 self.value = None
 
-    def get_keypath(self):
+    def get_keypath(self, field):
         if self.lookup in ('=', 'istrue', 'isfalse'):
-            return self.field
+            return field
 
         if self.lookup in ('isnull', 'isnotnull'):
-            return f'{self.field}__isnull'
+            return f'{field}__isnull'
 
-        return f'{self.field}__{self.lookup}'
+        return f'{field}__{self.lookup}'
 
     def get_value(self):
         if self.lookup in ('isnull', 'istrue'):
@@ -163,12 +174,17 @@ class DynamicFilterTerm(models.Model):
         return self.value
 
     def as_q(self):
-        term = {self.get_keypath(): self.get_value()}
+        terms = [
+            {self.get_keypath(field): self.get_value()}
+            for field in self.field.split('|')
+        ]
+
+        q = reduce(or_, (Q(**term) for term in terms))
 
         return (
-            ~Q(**term)
+            ~q
             if self.op == '!' else
-            Q(**term)
+            q
         )
 
 
